<?php

namespace Cenos\Master\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cenos\Master\Models\Prodcat;

class ProdcatPolicy
{

    /**
     * Determine if the given user can view the prodcat.
     *
     * @param UserPolicy $user
     * @param Prodcat $prodcat
     *
     * @return bool
     */
    public function view(UserPolicy $user, Prodcat $prodcat)
    {
        if ($user->canDo('master.prodcat.view') && $user->isAdmin()) {
            return true;
        }

        return $prodcat->user_id == user_id() && $prodcat->user_type == user_type();
    }

    /**
     * Determine if the given user can create a prodcat.
     *
     * @param UserPolicy $user
     * @param Prodcat $prodcat
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('master.prodcat.create');
    }

    /**
     * Determine if the given user can update the given prodcat.
     *
     * @param UserPolicy $user
     * @param Prodcat $prodcat
     *
     * @return bool
     */
    public function update(UserPolicy $user, Prodcat $prodcat)
    {
        if ($user->canDo('master.prodcat.edit') && $user->isAdmin()) {
            return true;
        }

        return $prodcat->user_id == user_id() && $prodcat->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given prodcat.
     *
     * @param UserPolicy $user
     * @param Prodcat $prodcat
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Prodcat $prodcat)
    {
        return $prodcat->user_id == user_id() && $prodcat->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given prodcat.
     *
     * @param UserPolicy $user
     * @param Prodcat $prodcat
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Prodcat $prodcat)
    {
        if ($user->canDo('master.prodcat.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given prodcat.
     *
     * @param UserPolicy $user
     * @param Prodcat $prodcat
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Prodcat $prodcat)
    {
        if ($user->canDo('master.prodcat.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
