<?php

namespace Cenos\Master\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cenos\Master\Models\Prodsource;

class ProdsourcePolicy
{

    /**
     * Determine if the given user can view the prodsource.
     *
     * @param UserPolicy $user
     * @param Prodsource $prodsource
     *
     * @return bool
     */
    public function view(UserPolicy $user, Prodsource $prodsource)
    {
        if ($user->canDo('master.prodsource.view') && $user->isAdmin()) {
            return true;
        }

        return $prodsource->user_id == user_id() && $prodsource->user_type == user_type();
    }

    /**
     * Determine if the given user can create a prodsource.
     *
     * @param UserPolicy $user
     * @param Prodsource $prodsource
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('master.prodsource.create');
    }

    /**
     * Determine if the given user can update the given prodsource.
     *
     * @param UserPolicy $user
     * @param Prodsource $prodsource
     *
     * @return bool
     */
    public function update(UserPolicy $user, Prodsource $prodsource)
    {
        if ($user->canDo('master.prodsource.edit') && $user->isAdmin()) {
            return true;
        }

        return $prodsource->user_id == user_id() && $prodsource->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given prodsource.
     *
     * @param UserPolicy $user
     * @param Prodsource $prodsource
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Prodsource $prodsource)
    {
        return $prodsource->user_id == user_id() && $prodsource->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given prodsource.
     *
     * @param UserPolicy $user
     * @param Prodsource $prodsource
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Prodsource $prodsource)
    {
        if ($user->canDo('master.prodsource.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given prodsource.
     *
     * @param UserPolicy $user
     * @param Prodsource $prodsource
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Prodsource $prodsource)
    {
        if ($user->canDo('master.prodsource.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
