<?php

namespace Cenos\Master\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cenos\Master\Models\Skill;

class SkillPolicy
{

    /**
     * Determine if the given user can view the skill.
     *
     * @param UserPolicy $user
     * @param Skill $skill
     *
     * @return bool
     */
    public function view(UserPolicy $user, Skill $skill)
    {
        if ($user->canDo('master.skill.view') && $user->isAdmin()) {
            return true;
        }

        return $skill->user_id == user_id() && $skill->user_type == user_type();
    }

    /**
     * Determine if the given user can create a skill.
     *
     * @param UserPolicy $user
     * @param Skill $skill
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('master.skill.create');
    }

    /**
     * Determine if the given user can update the given skill.
     *
     * @param UserPolicy $user
     * @param Skill $skill
     *
     * @return bool
     */
    public function update(UserPolicy $user, Skill $skill)
    {
        if ($user->canDo('master.skill.edit') && $user->isAdmin()) {
            return true;
        }

        return $skill->user_id == user_id() && $skill->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given skill.
     *
     * @param UserPolicy $user
     * @param Skill $skill
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Skill $skill)
    {
        return $skill->user_id == user_id() && $skill->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given skill.
     *
     * @param UserPolicy $user
     * @param Skill $skill
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Skill $skill)
    {
        if ($user->canDo('master.skill.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given skill.
     *
     * @param UserPolicy $user
     * @param Skill $skill
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Skill $skill)
    {
        if ($user->canDo('master.skill.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
