<?php

namespace Cenos\Master\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cenos\Master\Models\Skillcat;

class SkillcatPolicy
{

    /**
     * Determine if the given user can view the skillcat.
     *
     * @param UserPolicy $user
     * @param Skillcat $skillcat
     *
     * @return bool
     */
    public function view(UserPolicy $user, Skillcat $skillcat)
    {
        if ($user->canDo('master.skillcat.view') && $user->isAdmin()) {
            return true;
        }

        return $skillcat->user_id == user_id() && $skillcat->user_type == user_type();
    }

    /**
     * Determine if the given user can create a skillcat.
     *
     * @param UserPolicy $user
     * @param Skillcat $skillcat
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('master.skillcat.create');
    }

    /**
     * Determine if the given user can update the given skillcat.
     *
     * @param UserPolicy $user
     * @param Skillcat $skillcat
     *
     * @return bool
     */
    public function update(UserPolicy $user, Skillcat $skillcat)
    {
        if ($user->canDo('master.skillcat.edit') && $user->isAdmin()) {
            return true;
        }

        return $skillcat->user_id == user_id() && $skillcat->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given skillcat.
     *
     * @param UserPolicy $user
     * @param Skillcat $skillcat
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Skillcat $skillcat)
    {
        return $skillcat->user_id == user_id() && $skillcat->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given skillcat.
     *
     * @param UserPolicy $user
     * @param Skillcat $skillcat
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Skillcat $skillcat)
    {
        if ($user->canDo('master.skillcat.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given skillcat.
     *
     * @param UserPolicy $user
     * @param Skillcat $skillcat
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Skillcat $skillcat)
    {
        if ($user->canDo('master.skillcat.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
