<?php

namespace Cenos\Master\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cenos\Master\Models\Sourcecat;

class SourcecatPolicy
{

    /**
     * Determine if the given user can view the sourcecat.
     *
     * @param UserPolicy $user
     * @param Sourcecat $sourcecat
     *
     * @return bool
     */
    public function view(UserPolicy $user, Sourcecat $sourcecat)
    {
        if ($user->canDo('master.sourcecat.view') && $user->isAdmin()) {
            return true;
        }

        return $sourcecat->user_id == user_id() && $sourcecat->user_type == user_type();
    }

    /**
     * Determine if the given user can create a sourcecat.
     *
     * @param UserPolicy $user
     * @param Sourcecat $sourcecat
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('master.sourcecat.create');
    }

    /**
     * Determine if the given user can update the given sourcecat.
     *
     * @param UserPolicy $user
     * @param Sourcecat $sourcecat
     *
     * @return bool
     */
    public function update(UserPolicy $user, Sourcecat $sourcecat)
    {
        if ($user->canDo('master.sourcecat.edit') && $user->isAdmin()) {
            return true;
        }

        return $sourcecat->user_id == user_id() && $sourcecat->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given sourcecat.
     *
     * @param UserPolicy $user
     * @param Sourcecat $sourcecat
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Sourcecat $sourcecat)
    {
        return $sourcecat->user_id == user_id() && $sourcecat->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given sourcecat.
     *
     * @param UserPolicy $user
     * @param Sourcecat $sourcecat
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Sourcecat $sourcecat)
    {
        if ($user->canDo('master.sourcecat.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given sourcecat.
     *
     * @param UserPolicy $user
     * @param Sourcecat $sourcecat
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Sourcecat $sourcecat)
    {
        if ($user->canDo('master.sourcecat.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
