<?php

namespace Cenos\Master\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cenos\Master\Models\Storetype;

class StoretypePolicy
{

    /**
     * Determine if the given user can view the storetype.
     *
     * @param UserPolicy $user
     * @param Storetype $storetype
     *
     * @return bool
     */
    public function view(UserPolicy $user, Storetype $storetype)
    {
        if ($user->canDo('master.storetype.view') && $user->isAdmin()) {
            return true;
        }

        return $storetype->user_id == user_id() && $storetype->user_type == user_type();
    }

    /**
     * Determine if the given user can create a storetype.
     *
     * @param UserPolicy $user
     * @param Storetype $storetype
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('master.storetype.create');
    }

    /**
     * Determine if the given user can update the given storetype.
     *
     * @param UserPolicy $user
     * @param Storetype $storetype
     *
     * @return bool
     */
    public function update(UserPolicy $user, Storetype $storetype)
    {
        if ($user->canDo('master.storetype.edit') && $user->isAdmin()) {
            return true;
        }

        return $storetype->user_id == user_id() && $storetype->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given storetype.
     *
     * @param UserPolicy $user
     * @param Storetype $storetype
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Storetype $storetype)
    {
        return $storetype->user_id == user_id() && $storetype->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given storetype.
     *
     * @param UserPolicy $user
     * @param Storetype $storetype
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Storetype $storetype)
    {
        if ($user->canDo('master.storetype.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given storetype.
     *
     * @param UserPolicy $user
     * @param Storetype $storetype
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Storetype $storetype)
    {
        if ($user->canDo('master.storetype.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
