<?php

namespace Cenos\Master\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cenos\Master\Models\Topiccat;

class TopiccatPolicy
{

    /**
     * Determine if the given user can view the topiccat.
     *
     * @param UserPolicy $user
     * @param Topiccat $topiccat
     *
     * @return bool
     */
    public function view(UserPolicy $user, Topiccat $topiccat)
    {
        if ($user->canDo('master.topiccat.view') && $user->isAdmin()) {
            return true;
        }

        return $topiccat->user_id == user_id() && $topiccat->user_type == user_type();
    }

    /**
     * Determine if the given user can create a topiccat.
     *
     * @param UserPolicy $user
     * @param Topiccat $topiccat
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('master.topiccat.create');
    }

    /**
     * Determine if the given user can update the given topiccat.
     *
     * @param UserPolicy $user
     * @param Topiccat $topiccat
     *
     * @return bool
     */
    public function update(UserPolicy $user, Topiccat $topiccat)
    {
        if ($user->canDo('master.topiccat.edit') && $user->isAdmin()) {
            return true;
        }

        return $topiccat->user_id == user_id() && $topiccat->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given topiccat.
     *
     * @param UserPolicy $user
     * @param Topiccat $topiccat
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Topiccat $topiccat)
    {
        return $topiccat->user_id == user_id() && $topiccat->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given topiccat.
     *
     * @param UserPolicy $user
     * @param Topiccat $topiccat
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Topiccat $topiccat)
    {
        if ($user->canDo('master.topiccat.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given topiccat.
     *
     * @param UserPolicy $user
     * @param Topiccat $topiccat
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Topiccat $topiccat)
    {
        if ($user->canDo('master.topiccat.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
