<?php

namespace Cenos\Master\Providers;

use Illuminate\Support\ServiceProvider;

class MasterServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'master');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'master');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerMaster();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerMaster()
    {
        $this->app->bind('master', function($app) {
            return new Master($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Master', 'Lavalite\Master\Facades\Master');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('cenos.master', function ($app) {
            return $this->app->make('Cenos\Master\Master');
        });

        // Bind Store to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\StoreRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\StoreRepository::class
        );
        // Bind Product to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\ProductRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\ProductRepository::class
        );
        // Bind Topic to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\TopicRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\TopicRepository::class
        );
        // Bind Region to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\RegionRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\RegionRepository::class
        );
        // Bind Storetype to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\StoretypeRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\StoretypeRepository::class
        );
        // Bind Prodsource to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\ProdsourceRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\ProdsourceRepository::class
        );
        // Bind Prodcat to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\ProdcatRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\ProdcatRepository::class
        );
        // Bind Topiccat to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\TopiccatRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\TopiccatRepository::class
        );
        // Bind Sourcecat to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\SourcecatRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\SourcecatRepository::class
        );
        // Bind Source to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\SourceRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\SourceRepository::class
        );
        // Bind Skill to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\SkillRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\SkillRepository::class
        );
        // Bind Skillcat to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\SkillcatRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\SkillcatRepository::class
        );
        // Bind Topictype to repository
        $this->app->bind(
            'Cenos\Master\Interfaces\TopictypeRepositoryInterface',
            \Cenos\Master\Repositories\Eloquent\TopictypeRepository::class
        );

        $this->app->register(\Cenos\Master\Providers\AuthServiceProvider::class);
                $this->app->register(\Cenos\Master\Providers\EventServiceProvider::class);
        
        $this->app->register(\Cenos\Master\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and master's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/master.php', 'master'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeMaster::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['cenos.master'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('cenos/master.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/master')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/master')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
